pub struct NSWindowOcclusionState(/* private fields */);Implementations
Sourceimpl NSWindowOcclusionState
impl NSWindowOcclusionState
pub const NSWindowOcclusionStateVisible: Self
Sourceimpl NSWindowOcclusionState
impl NSWindowOcclusionState
Sourcepub const fn empty() -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn empty() -> Self
Get a flags value with all bits unset.
Sourcepub const fn all() -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn all() -> Self
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> NSUInteger
๐Deprecated: use the objc2-app-kit crate instead
pub const fn bits(&self) -> NSUInteger
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: NSUInteger) -> Option<Self>
๐Deprecated: use the objc2-app-kit crate instead
pub const fn from_bits(bits: NSUInteger) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: NSUInteger) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn from_bits_truncate(bits: NSUInteger) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: NSUInteger) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn from_bits_retain(bits: NSUInteger) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
๐Deprecated: use the objc2-app-kit crate instead
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesnโt
correspond to any named flag.
Sourcepub const fn is_empty(&self) -> bool
๐Deprecated: use the objc2-app-kit crate instead
pub const fn is_empty(&self) -> bool
Whether all bits in this flags value are unset.
Sourcepub const fn is_all(&self) -> bool
๐Deprecated: use the objc2-app-kit crate instead
pub const fn is_all(&self) -> bool
Whether all known bits in this flags value are set.
Sourcepub const fn intersects(&self, other: Self) -> bool
๐Deprecated: use the objc2-app-kit crate instead
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
๐Deprecated: use the objc2-app-kit crate instead
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: Self)
๐Deprecated: use the objc2-app-kit crate instead
pub fn insert(&mut self, other: Self)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: Self)
๐Deprecated: use the objc2-app-kit crate instead
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove wonโt truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
๐Deprecated: use the objc2-app-kit crate instead
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
๐Deprecated: use the objc2-app-kit crate instead
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference wonโt truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
๐Deprecated: use the objc2-app-kit crate instead
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl NSWindowOcclusionState
impl NSWindowOcclusionState
Sourcepub const fn iter(&self) -> Iter<NSWindowOcclusionState>
๐Deprecated: use the objc2-app-kit crate instead
pub const fn iter(&self) -> Iter<NSWindowOcclusionState>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<NSWindowOcclusionState>
๐Deprecated: use the objc2-app-kit crate instead
pub const fn iter_names(&self) -> IterNames<NSWindowOcclusionState>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.